@@ -33,17 +33,23 @@ DEFAULT_ADDTHIS_USER = getattr(settings, 'DEFAULT_ADDTHIS_USER', None)
 # regex used to find links in an article
 LINK_RE = re.compile('<a.*?href="(.*?)".*?>(.*?)</a>', re.I|re.M)
 TITLE_RE = re.compile('<title>(.*?)</title>', re.I|re.M)
-TAG_RE = re.compile('[^a-z0-9\-_\+\@\$\%\^\*\(\)\{\}\[\]\:\'\<\>,=\.\|\\\]?', re.I)
+TAG_RE = re.compile('[^a-z0-9\-_\+\:\.]?', re.I)
 
 def get_name(user):
     """
     Provides a way to fall back to a user's username if their full name has not
     been entered.
     """
-    if len(user.get_full_name().strip()):
-        return user.get_full_name()
-    else:
-        return user.username
+    key = 'username_for_%s' % user.id
+    name = cache.get(key)
+    if not name:
+        if len(user.get_full_name().strip()):
+            name = user.get_full_name()
+        else:
+            name = user.username
+        cache.set(key, name, 86400)
+
+    return name
 User.get_name = get_name
 
 class Tag(models.Model):
@@ -52,18 +58,28 @@ class Tag(models.Model):
     def __unicode__(self):
         return self.name
 
+    @staticmethod
+    def clean(name):
+        """Replace spaces with dashes, in case someone adds such a tag manually"""
+
+        name = name.replace(' ', '-')
+        name = TAG_RE.sub('', name)
+        return name.lower().strip()
+
     def save(self, *args, **kwargs):
         """Cleans up any characters I don't want in a URL"""
 
-        # replace spaces with dashes, in case someone adds such a tag manually
-        self.name = self.name.replace(' ', '-')
-        self.name = TAG_RE.sub('', self.name)
+        self.name = Tag.clean(self.name)
         super(Tag, self).save(*args, **kwargs)
 
     @models.permalink
     def get_absolute_url(self):
         return ('articles_display_tag', (self.name,))
 
+    @property
+    def rss_name(self):
+        return u'tags/%s' % self.name
+
     class Meta:
         ordering = ('name',)
 
